local Target = Class("target")

Target.marks = {center = .1, betweenIn = .3, betweenOut = .6, out = 1}

function Target:initialize()
  math.randomseed(os.time())
  self.body = love.physics.newBody(pWorld, math.random(600, 1100), math.random(-400, 0))
  local size = math.random(80, 200)
  self.size = size
  self.width = size/4
  self.height = size
  self.shape = love.physics.newRectangleShape(self.width, self.height)
  self.body:setAngle(math.random()*math.pi/2 - math.pi/4)
  self.fixture = love.physics.newFixture(self.body, self.shape)
  self.fixture:setUserData(self)
end

function Target:collided(fix1, fix2)
  self.body:destroy()
  self.timer = 3
  fix2:getBody():setLinearVelocity(0, 0)
  --Updater:remove("bow", self.__updaterkey)
  --self.createNew = true
end

function Target:draw()
  local width = self.width
  local height = self.height
  
  if self.timer then
    love.graphics.push()
    love.graphics.scale(5)
    love.graphics.setColor(255, 255, 255)
    love.graphics.print(math.floor(self.timer)+1, 95, -85)
    love.graphics.pop()
  else
    love.graphics.push()
    love.graphics.translate(self.body:getPosition())
    love.graphics.rotate(self.body:getAngle())
    self:drawMarks()
    love.graphics.pop()
  end
end

function Target:drawMarks()
  local width = self.width
  local height = self.height
  love.graphics.setColor(255, 255, 255)
  love.graphics.rectangle("fill", -width/2, -height*Target.marks.out/2, width, height*self.marks.out)
  love.graphics.setColor(180, 40, 40)
  love.graphics.rectangle("fill", -width/2, -height*Target.marks.betweenOut/2, width, height*self.marks.betweenOut)
  love.graphics.setColor(255, 255, 255)
  love.graphics.rectangle("fill", -width/2, -height*Target.marks.betweenIn/2, width, height*self.marks.betweenIn)  
  love.graphics.setColor(180, 40, 40)
  love.graphics.rectangle("fill", -width/2, -height*Target.marks.center/2, width, height*self.marks.center)
end

function Target:update(dt)
  if self.timer then
    self.timer = self.timer - dt
    if self.timer<0 then
      Updater:remove("bow", self.__updaterkey)
      self.createNew = true
    end
  end
  if self.createNew then
    Updater:add("bow", Target:new())
    self.createNew = false
  end
end

return Target