local function physics__collided(fix1, fix2, contact)
  local obj1 = fix1:getUserData()
  local obj2 = fix2:getUserData()
  if obj1 and obj1.collided then
    obj1:collided(fix1, fix2, contact)
  end
  if obj2 and obj2.collided then
    obj2:collided(fix2, fix1, contact)
  end
end

function love.load()
  Class = require("libs.middleclass")
  Updater = require("updater"):new()
  pWorld = love.physics.newWorld(0, 90, false)
  pWorld:setCallbacks(physics__collided)
  p__debugDraw = require("libs.debug.physicsDebug")
  
  Updater:addList("bow")
  Updater:add("bow", require("classes.bow"):new())
  Updater:add("bow", require("classes.target"):new())
end

local translateX = 100
local translateY = 500
local scale = .6
function love.draw()
  love.graphics.push("all")
  love.graphics.translate(translateX, translateY)
  love.graphics.scale(scale)
  p__debugDraw(pWorld, -1000, -1000, 10000, 10000)
  
  local mx, my = d__getMousePosition()
  love.graphics.circle("fill", mx, my, 2)
  
  Updater:draw()
  love.graphics.pop()
  
  love.graphics.print("FPS: " .. love.timer.getFPS() .. "\nControls:\nQ/E: Zoom in/out\nA/D: rotate bow\nLeft click(Hold): Grab line (Release mouse to release line and move the mouse around to pull the line\nS: Create arrow (Only works when the line is grabbed)\n\nNow try and shoot the targets!")
end

local steps = 8
function love.update(dt)
  dt = dt>0.018 and 0.018 or dt
  for i = 1, steps do
    Updater:update(dt/steps)
    pWorld:update(dt/steps)
  end
  
  if love.keyboard.isDown("q") then
    scale = scale - scale *.9*dt
  end
  if love.keyboard.isDown("e") then
    scale = scale + scale *.9*dt
  end
end

function love.mousepressed(x, y, button)
  Updater:mousepressed(x, y, button)
end

function love.mousereleased(x, y, button)
  Updater:mousereleased(x, y, button)
end

function love.keypressed(key)
  Updater:keypressed(key)
end

function d__getMousePosition()
  local mx, my = love.mouse.getPosition()
  return (mx-translateX)/scale, (my-translateY)/scale
end